summaryrefslogtreecommitdiff
path: root/licensing
diff options
context:
space:
mode:
authorMike Frysinger <vapier@chromium.org>2014-04-02 22:16:42 -0400
committerchrome-internal-fetch <chrome-internal-fetch@google.com>2014-04-15 03:49:25 +0000
commitfd96931fef6be4d392854ae48724421a2aa07f6c (patch)
treec5ed5235b2e459dafe387ab27013c83f7937b698 /licensing
parent5aa26b1f4ed8c7f77e54d1390af8c58e9478e71e (diff)
downloadchromite-fd96931fef6be4d392854ae48724421a2aa07f6c.tar.gz
switch from chromeos-base/chromeos to virtual/target-os
This is mechanical -- virtual/target-os depends on chromeos, so there shouldn't be any real difference in the build. BUG=chromium:329920 TEST=`cbuildbot beaglebone` passes TEST=`./buildbot/run_tests` passes CQ-DEPEND=CL:192991 Change-Id: I876268086b715f7cff868e630cb05fd91067b11e Reviewed-on: https://chromium-review.googlesource.com/192487 Reviewed-by: Mike Frysinger <vapier@chromium.org> Commit-Queue: Mike Frysinger <vapier@chromium.org> Tested-by: Mike Frysinger <vapier@chromium.org>
Diffstat (limited to 'licensing')
-rw-r--r--licensing/licenses.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/licensing/licenses.py b/licensing/licenses.py
index 4c63418a6..af8631049 100644
--- a/licensing/licenses.py
+++ b/licensing/licenses.py
@@ -21,8 +21,8 @@ Recommended build:
sudo rm -rf /build/$board
sudo install -o $(whoami) -d /build/x86-alex//var/lib/licenses/
cd ~/trunk/src/scripts
# If you wonder why we need to build
# chromeos just to run emerge -p -v chromeos-base/chromeos on it, we don't.
# However, later we run ebuild unpack, and this will apply patches and run
# configure. Configure will fail due to aclocal macros missing in
# /build/x86-alex/usr/share/aclocal (those are generated during build).
@@ -1084,7 +1084,7 @@ def ListInstalledPackages(board, all_packages=False):
# all packages.
# If it's set to False, it will only generate a licensing file that contains
# packages used for a release build (as determined by the dependencies for
- # chromeos-base/chromeos).
+ # virtual/target-os).
if all_packages:
# The following returns all packages that were part of the build tree
@@ -1101,7 +1101,7 @@ def ListInstalledPackages(board, all_packages=False):
# Note that it also contains packages that are in the build as
# defined by build_packages but not part of the image we ship.
args = ["emerge-%s" % board, "--with-bdeps=y", "--usepkgonly",
- "--emptytree", "--pretend", "--color=n", "chromeos-base/chromeos"]
+ "--emptytree", "--pretend", "--color=n", "virtual/target-os"]
emerge = cros_build_lib.RunCommand(args, print_cmd=debug,
redirect_stdout=True).output.splitlines()
# Another option which we've decided not to use, is bdeps=n. This outputs
@@ -21,8 +21,8 @@ Recommended build:
sudo install -o $(whoami) -d /build/x86-alex//var/lib/licenses/
cd ~/trunk/src/scripts
- # If you wonder why we need to build
- # chromeos just to run emerge -p -v chromeos-base/chromeos on it, we don't.
+ # If you wonder why we need to build Chromium OS just to run
+ # `emerge -p -v virtual/target-os` on it, we don't.
# However, later we run ebuild unpack, and this will apply patches and run
# configure. Configure will fail due to aclocal macros missing in